(** Module used internally to build and render on textures
  larger than SDL textures. *)

val log_src : Logs.src

type t

val destroy : t -> unit
val max_texture_size : (int * int) option ref
val create :
  ?format:Tsdl.Sdl.Pixel.format_enum ->
  ?access:Tsdl.Sdl.Texture.access -> Tsdl.Sdl.renderer -> w:int -> h:int -> t
val set_blend_mode : t -> Tsdl.Sdl.Blend.mode -> unit
val set_alpha_mod : t -> int -> unit
val set_color_mod : t -> int -> int -> int -> unit
val from_texture : Tsdl.Sdl.renderer -> Tsdl.Sdl.texture -> t
val from_scaled_texture : Tsdl.Sdl.renderer ->
  destroy_orig:bool -> w:int -> h:int -> Tsdl.Sdl.texture -> t
val query :
  t ->
  (Tsdl.Sdl.Pixel.format_enum * Tsdl.Sdl.Texture.access * (int * int), 'a)
  result
val from_surface : Tsdl.Sdl.renderer -> Tsdl.Sdl.surface -> t
val with_renderer : (Tsdl.Sdl.renderer -> 'a) -> Tsdl.Sdl.renderer -> 'a

val fill_rect : Tsdl.Sdl.renderer -> t -> G.t option -> int32 -> unit
val draw_rect :
  Tsdl.Sdl.renderer -> t -> x:int -> y:int -> w:int -> h:int -> int32 -> unit
val draw_rect_r : Tsdl.Sdl.renderer -> t -> G.t -> int32 -> unit
val draw_point : Tsdl.Sdl.renderer -> t -> x:int -> y:int -> int32 -> unit
val render_copy : src:G.t -> dst:G.t -> Tsdl.Sdl.renderer -> t -> unit
val copy :
  Tsdl.Sdl.renderer -> from:t -> src:G.t -> x:int -> y:int -> t -> unit
val clear: Tsdl.Sdl.renderer -> t -> unit