(** Bindings to libiconv. *)

type iconv (** A libiconv iconv_t value *)

(** See {{:https://www.gnu.org/savannah-checkouts/gnu/libiconv/documentation/libiconv-1.17/iconv_open.3.html} iconv_open documentation}.
  Raises [Unix_error] in case something goes wrong.
*)
val iconv_open : fromcode:string -> tocode:string -> iconv

(** See {{:https://www.gnu.org/savannah-checkouts/gnu/libiconv/documentation/libiconv-1.17/iconv_close.3.html} iconv_close documentation}.
  Raises [Unix_error] in case something goes wrong.
*)
val iconv_close : iconv -> unit

(** Applies the given converter to the given string.
  Raises [Unix_error] in case something goes wrong.
*)
val iconv : iconv -> string -> string

(** Convenient function to create a character converter,
  apply it on the given string, close the converted and return
  the converted string.
  Raises [Unix_error] in case something goes wrong.
*)
val iconv_string : fromcode:string -> tocode:string -> string -> string

(** Static list of encoding names handled by iconv. *)
val encoding_names : string list